==============
Citing CLARITE
==============

If you use CLARITE in a scientific publication, please consider citing:

1.
Lucas AM, et al (2019)
`CLARITE facilitates the quality control and analysis process for EWAS of metabolic-related traits. <https://www.frontiersin.org/article/10.3389/fgene.2019.01240>`_
*Frontiers in Genetics*: 10, 1240

BibTeX entry::

    @article{lucas2019clarite,
      title={CLARITE facilitates the quality control and analysis process for EWAS of metabolic-related traits},
      author={Lucas, Anastasia M. and Palmiero, Nicole E. and McGuigan, John and Passero, Kristin and Zhou, Jiayan and Orie, Deven and Ritchie, Marylyn D. and Hall, Molly A.},
      journal={Frontiers in Genetics},
      volume={10},
      pages={1240},
      year={2019},
      publisher={Frontiers},
      url={https://www.frontiersin.org/article/10.3389/fgene.2019.01240},
      doi={10.3389/fgene.2019.01240}
    }

2.
Passero K, et al (2020)
`Phenome-wide association studies on cardiovascular health and fatty acids considering phenotype quality control practices for epidemiological data. <https://www.worldscientific.com/doi/abs/10.1142/9789811215636_0058>`_
*Pacific Symposium on Biocomputing*: 25, 659


BibTeX entry::

    @inproceedings{passero2020phenome,
      title={Phenome-wide association studies on cardiovascular health and fatty acids considering phenotype quality control practices for epidemiological data.},
      author={Passero, Kristin and He, Xi and Zhou, Jiayan and Mueller-Myhsok, Bertram and Kleber, Marcus E and Maerz, Winfried and Hall, Molly A},
      booktitle={Pacific Symposium on Biocomputing},
      volume={25},
      pages={659},
      year={2020},
      organization={World Scientific},
      URL={https://www.worldscientific.com/doi/abs/10.1142/9789811215636_0058},
      DOI={10.1142/9789811215636_0058}
    }
